<!DOCTYPE html>
<html lang="ja">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ status }}</title>
</head>
<body>
    <div class="error_container">
        <div class="error_name">{{ status }}</div>
        <div class="error_message">{{ message }}</div>
    </div>
</body>
</html>
<style>
    @import url('https://fonts.googleapis.com/css2?family=Google+Sans:ital,opsz,wght@0,17..18,400..700;1,17..18,400..700&family=Noto+Sans+JP:wght@100..900&display=swap');
    body{
        position: relative;
        width: 100%;
        min-width: 300px;
        height: 100vh;
        display: flex;
        justify-content: center;
        align-items: center;
        margin: 0;

        font-family: 'Noto Sans JP', 'Hiragino Sans', 'ヒラギノ角ゴシック', 'Yu Gothic','游ゴシック';
        background: linear-gradient(135deg, #ffffff, 90%, #ff0050);
    }

    .error_container{
        position: relative;
        padding: 30px;
    }
    .error_name{
        font-size: 2rem;
        font-family: "Google Sans";
        color: rgb(246, 60, 60);
    }
    .error_message{
        font-size: 1rem;
        font-family: "Google Sans";
    }
</style>